%define releasedate 20210807

Name:		foomatic-db
Version:	4.0
Release:	%mkrel 3.%{releasedate}.3
Epoch:		1
Summary:	Foomatic printer/driver database
License:	GPLv2 and MIT
Group:		System/Servers
Url:		https://openprinting.org/
Source:		https://www.openprinting.org/download/foomatic/%{name}-%{version}-%{releasedate}.tar.gz
# Perl script to clean up Manufacturer entries in the PPD files, so that
# drivers are sorted by the printer manufacturer in the graphical frontends
Source2:	cleanppd.pl.bz2
Patch0:		foomatic-db-20130312-cp_argument_list_too_long.diff
Patch1:		foomatic-db-device-ids.patch
Requires:	foomatic-db-engine
Conflicts:	cups-drivers-foo2zjs < 0.0-0.20091014.1
BuildArch:	noarch
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	cups
BuildRequires:	cups-common
BuildRequires:	foomatic-db-engine
# Make sure we get postscriptdriver tags:
BuildRequires:	python-cups
BuildRequires:	perl

%description
Foomatic is a comprehensive, spooler-independent database of printers,
printer drivers, and driver descriptions. It contains utilities to
generate PPD (Postscript Printer Description) files and printer queues
for CUPS, LPD, GNUlpr, LPRng, PPR, and PDQ using the database. There
is also the possibility to read the PJL options out of PJL-capable
laser printers and take them into account at the driver description
file generation.

There are spooler-independent command line interfaces to manipulate
queues (foomatic-configure) and to print files/manipulate jobs
(foomatic printjob).
 
This package is the Foomatic database, an XML database containing
information about the capabilities of near 1000 printers and around
250 drivers. Especially it contains the information how and with which
options the drivers have to be executed.

%prep

##### FOOMATIC

# Source trees for installation
%setup -q -n %{name}-%{releasedate}
%patch -P 0 -p0
# foomatic-db patches
# Don't use "-b" when patching PPD files as the backups will be packaged.

# Device IDs for:
# Brother MFC-8840D (#678065)
# HP LaserJet M1522nf MFP (#745499)
# Lexmark C453 (#770169)
# HP DeskJet 720C (bug #797099)
# Kyocera FS-1118MFP (bug #782377)
%patch -P 1 -p1

# Use sed instead of perl in the PPDs (bug #512739).
find db/source/PPD -type f -name '*.ppd' | xargs perl -pi -e 's,perl -p,sed,'

%build
# Makefile generation ("./make_configure" for CVS snapshots)
./make_configure
# Fix for lib64 architectures, avoid patch
perl -pi -e "s@/usr/lib/(cups|pdq|ppr)@%{_libdir}/\1@g" configure

# We do not compress the PPDs now, so that we can do a clean-up
%configure --disable-gzip-ppds

# "make" is not needed for this package, there is nothing to build

# Delete drivers which are not on the distro (obsolete drivers which are
# replaced by a new driver with a different name)
# "stp" replaced by "gimp-print"/"gutenprint"
rm -f db/source/driver/stp.xml
# "cZ11" replaced by "cZ11somsom"
rm -f db/source/driver/cZ11.xml
# "cZ11somsom" replaced by "lz11"
rm -f db/source/driver/cZ11somsom.xml
# "hpdj" replaced by "pcl3"
rm -f db/source/driver/hpdj.xml
# "lxm3200[mcp]" replaced by "lxm3200"
rm -f db/source/driver/lxm3200[mcp].xml
# "lxm3200" replaced by "lxm3200-tweaked"
rm -f db/source/driver/lxm3200.xml
# Japanese drivers which are not in our GhostScript
rm -f db/source/driver/bjc800j.xml
rm -f db/source/driver/bj10.xml

# These drivers come with their own Foomatic data. Remove the files
# from this package
rm -f db/source/*/gimp-print*.xml
rm -f db/source/*/gutenprint*.xml
rm -f db/source/*/foo2*.xml
rm -f db/source/*/lz11*.xml
rm -f db/source/*/m2300w*.xml
rm -f db/source/*/m2400w*.xml
rm -f db/source/[do]*/*[Pp]touch*.xml

# foo2zjs files
rm -f \
	db/source/printer/HP-Color_LaserJet_1500.xml \
	db/source/printer/HP-Color_LaserJet_1600.xml \
	db/source/printer/HP-Color_LaserJet_2600n.xml \
	db/source/printer/HP-LaserJet_1000.xml \
	db/source/printer/HP-LaserJet_1005.xml \
	db/source/printer/HP-LaserJet_1020.xml \
	db/source/printer/HP-LaserJet_1022.xml \
	db/source/printer/HP-LaserJet_M1005_MFP.xml \
	db/source/printer/Minolta-magicolor_2300_DL.xml \
	db/source/printer/Minolta-magicolor_2430_DL.xml \
	db/source/printer/Samsung-CLP-300.xml \
	db/source/printer/Samsung-CLP-600.xml \
	db/source/printer/Xerox-Phaser-6115MFP.xml

# m2300w files
rm -f \
	db/source/printer/Minolta-magicolor_2300W.xml \
	db/source/printer/Minolta-magicolor_2400W.xml

# ptouch files
rm -f \
	db/source/printer/Brother-PT-1500PC.xml \
	db/source/printer/Brother-PT-18R.xml \
	db/source/printer/Brother-PT-1950.xml \
	db/source/printer/Brother-PT-1950VP.xml \
	db/source/printer/Brother-PT-1960.xml \
	db/source/printer/Brother-PT-2420PC.xml \
	db/source/printer/Brother-PT-2450DX.xml \
	db/source/printer/Brother-PT-2500PC.xml \
	db/source/printer/Brother-PT-2600.xml \
	db/source/printer/Brother-PT-2610.xml \
	db/source/printer/Brother-PT-3600.xml \
	db/source/printer/Brother-PT-550A.xml \
	db/source/printer/Brother-PT-9200DX.xml \
	db/source/printer/Brother-PT-9200PC.xml \
	db/source/printer/Brother-PT-9400.xml \
	db/source/printer/Brother-PT-9500PC.xml \
	db/source/printer/Brother-PT-9600.xml \
	db/source/printer/Brother-PT-PC.xml \
	db/source/printer/Brother-QL-500.xml \
	db/source/printer/Brother-QL-550.xml \
	db/source/printer/Brother-QL-650TD.xml

# Delete drivers with empty command line prototype, they would give
# unusable printer/driver combos.
FOOMATICDB=`pwd` %{_sbindir}/foomatic-cleanupdrivers

# Correct recommended driver "gimp-print" or "gutenprint", must be 
# "gutenprint-ijs.5.0".
for f in db/source/printer/*.xml; do
	perl -p -i -e 's:<driver>(gimp-|guten)print</driver>:<driver>gutenprint-ijs.5.0</driver>:' $f
done

# Fixed default paper tray for HP Business Inkjet 2800.
perl -p -i -e 's/(\*DefaultInputSlot:\s+)Auto/$1Tray1/' db/source/PPD/HP/business_inkjet/HP_Business_Inkjet_2800.ppd
# Fixed device ID lines in the HP PPDs
perl -p -i -e 's/1284DeviceId/1284DeviceID/' db/source/PPD/HP/*/*.ppd

%install
# Do not use "make" macro, as parallelized build of Foomatic does not
# work.

# Install data files
make	PREFIX=%{_prefix} \
        DESTDIR=%{buildroot} \
        install

# Uncompress Perl script for cleaning up the PPD files
bzcat %{SOURCE2} > ./cleanppd.pl
chmod a+rx ./cleanppd.pl

# Do the clean-up
find %{buildroot}%{_datadir}/foomatic/db/source/PPD -name "*.ppd" -exec ./cleanppd.pl '{}' \;

# Remove PPDs which are not Adobe-compliant and therefore not working with
# CUPS 1.1.20 or newer
for ppd in `find %{buildroot}%{_datadir}/foomatic/db/source/PPD -name "*.ppd.gz"`
do
	cupstestppd -q $ppd || (
		rm -f $ppd && \
		echo "$ppd not Adobe-compliant. Deleted." && \
		echo $ppd >> deletedppds-%{name}-%{version}-%{release}.txt
	)
done

##### GENERAL STUFF

# Correct permissions
for f in %{buildroot}%{_datadir}/foomatic/db/source/*/*.xml; do
  chmod a-x $f
done
chmod a-x %{buildroot}%{_datadir}/foomatic/db/oldprinterids

##### SCRIPTS

# Restart the CUPS daemon when it is running, but do not start it when it
# is not running. The restart of the CUPS daemon updates the CUPS-internal
# PPD index

%post
/sbin/service cups condrestart > /dev/null 2>/dev/null || :

%postun
/sbin/service cups condrestart > /dev/null 2>/dev/null || :

##### FILES

%files
%doc README USAGE COPYING
%{_datadir}/foomatic/db
%{_datadir}/foomatic/xmlschema
%{_datadir}/cups/model/foomatic-db-ppds


%changelog
* Sat Dec 21 2024 pterjan <pterjan> 1:4.0-3.20210807.3.mga10
+ Revision: 2127336
- Rebuild for patchN deprecation

* Mon Mar 28 2022 umeabot <umeabot> 1:4.0-3.20210807.2.mga9
+ Revision: 1830500
- Mageia 9 Mass Rebuild

* Sun Aug 08 2021 luigiwalser <luigiwalser> 1:4.0-3.20210807.1.mga9
+ Revision: 1740177
- update to 20210807 snapshot

* Sun Nov 15 2020 luigiwalser <luigiwalser> 1:4.0-3.20201115.1.mga8
+ Revision: 1646404
- update to 20201115 snapshot

* Thu Feb 13 2020 umeabot <umeabot> 1:4.0-3.20180326.2.mga8
+ Revision: 1513516
- Mageia 8 Mass Rebuild

* Tue Sep 25 2018 pterjan <pterjan> 1:4.0-3.20180326.1.mga7
+ Revision: 1305223
- Make the release higher than previous one
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Update to 4.0-1.20180326

* Sun Jan 01 2017 luigiwalser <luigiwalser> 1:4.0-3.20161231.1.mga6
+ Revision: 1078952
- update device info to 20161231 snapshot

* Fri Nov 11 2016 luigiwalser <luigiwalser> 1:4.0-3.20161111.1.mga6
+ Revision: 1066486
- update device info to 20161111 snapshot

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1:4.0-3.20150819.1.mga6
+ Revision: 918744
- update device info to 20150819 snapshot

* Thu Nov 13 2014 tv <tv> 1:4.0-3.20140709.4.mga5
+ Revision: 796711
- BR python-cups so that we got postscriptdriver provides

* Wed Oct 15 2014 umeabot <umeabot> 1:4.0-3.20140709.3.mga5
+ Revision: 749663
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:4.0-3.20140709.2.mga5
+ Revision: 679297
- Mageia 5 Mass Rebuild

* Wed Jul 09 2014 luigiwalser <luigiwalser> 1:4.0-3.20140709.1.mga5
+ Revision: 650903
- update device info to 20140709 snapshot

* Fri Jun 13 2014 luigiwalser <luigiwalser> 1:4.0-3.20140613.1.mga5
+ Revision: 636010
- update device info to 20140613 snapshot

* Sat Apr 26 2014 luigiwalser <luigiwalser> 1:4.0-3.20140426.1.mga5
+ Revision: 618288
- update device info to 20140426 snapshot

* Sat Mar 29 2014 luigiwalser <luigiwalser> 1:4.0-3.20140329.1.mga5
+ Revision: 609710
- update device info to 20140329 snapshot

* Sat Mar 15 2014 luigiwalser <luigiwalser> 1:4.0-3.20140315.1.mga5
+ Revision: 604009
- update device info to 20140315 snapshot

* Fri Feb 14 2014 luigiwalser <luigiwalser> 1:4.0-3.20140213.1.mga5
+ Revision: 590998
- update device info to 20140213 snapshot

* Sun Dec 22 2013 luigiwalser <luigiwalser> 1:4.0-3.20131222.1.mga4
+ Revision: 559711
- update device info to 20131222 snapshot

* Mon Oct 21 2013 umeabot <umeabot> 1:4.0-3.20130928.2.mga4
+ Revision: 538082
- Mageia 4 Mass Rebuild

* Sat Sep 28 2013 luigiwalser <luigiwalser> 1:4.0-3.20130928.1.mga4
+ Revision: 488412
- update device info to 20130928 snapshot

* Fri Sep 13 2013 luigiwalser <luigiwalser> 1:4.0-3.20130913.1.mga4
+ Revision: 478707
- update device info to 20130913 snapshot
- update patch 1 (from fedora)

* Thu Aug 08 2013 luigiwalser <luigiwalser> 1:4.0-3.20130808.1.mga4
+ Revision: 464762
- update device info to 20130808 snapshot

* Tue Mar 19 2013 luigiwalser <luigiwalser> 1:4.0-3.20130312.1.mga3
+ Revision: 404070
- update device info to 20130312 snapshot (sync with fedora)
- rediff patch 0

* Fri Jan 11 2013 umeabot <umeabot> 1:4.0-2.20101202.3.mga3
+ Revision: 350758
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ ahmad <ahmad>
- drop old conflicts

* Fri Jan 28 2011 dmorgan <dmorgan> 1:4.0-2.20101202.2.mga1
+ Revision: 43076
- Remove unneded hack
- Add fedora patches to add devices
- imported package foomatic-db

